#
# spec file for package zpaq
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         dversion 715
Name:           zpaq
Version:        7.15
Release:        bp154.2.22
Summary:        A journaling, incremental, deduplicating archiver
License:        SUSE-Public-Domain AND MIT
Group:          Productivity/Archiving/Compression
URL:            http://mattmahoney.net/dc/zpaq.html
Source0:        http://mattmahoney.net/dc/zpaq%{dversion}.zip
Source1:        %{name}.changes
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  unzip

%description
zpaq is a journaling, incremental, deduplicating archiver.
"Journaling" means that when you update a file or directory, both the
old and new versions are saved and can be extracted. "Incremental"
means that only those files whose last-modified date has changed
since the previous backup are added. For 100 GB of files, this
typically takes 1-2 minutes, vs. a few hours to create the first
version. "Deduplicating" means that identical files or fragments are
stored only once to save time and space.

%prep
%autosetup -c %{name}%{dversion}
dos2unix readme.txt COPYING

%build
%make_build CXXFLAGS="%{optflags}"

%install
%make_install \
  DESTDIR="%{?buildroot}" \
  LIBDIR="%{_libdir}" \
  BINDIR="%{_bindir}" \
  MANDIR="%{_mandir}" \
  INCLUDEDIR="%{_includedir}"

%files
%doc readme.txt
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Wed Apr 14 2021 Martin Pluskal <mpluskal@suse.com>
- Spec file cleanup
* Tue Feb 27 2018 jengelh@inai.de
- Trim Windows mention. Compact description.
* Mon Feb 19 2018 aloisio@gmx.com
- Update to version 7.15
  * Fixes incorrect JIT assembly of "a+= 128" in libzpaq.
  version 7.14
  * Faster backup to a network drive.
- Upstream removed separate shared library and so we drop
  - devel and libzpaq subpackages
* Sun Oct 23 2016 mpluskal@suse.com
- Small package cleanup and rename of devel package
* Sat May  7 2016 mpluskal@suse.com
- Update to 7.13
  * Removes requirement for separate  WinXP version. Fixes Intel
    and VS 2015 compiler errors.
  * Removes multi-part archive support, -nodelete, add -test, and
  - key prompt.
  * Updated Makefile to link libzpaq.o statically.
  * Fixes bug in extracting streaming archive with empty first
    file name.
  * Adds multi-part archives, -index. Some UI changes. Updates
    libzpaq.h, zpaq.pod.
  * Adds -repack, -encrypt. Updates libzpaq.cpp, zpaq.pod
  * Faster extract. Removes -encrypt (combined with -repack).
    Updates libzpaq.h, zpaq.pod. Apr. 29, 2016: added
    zpaq-gcc481.exe for older machines.
  * Adds support for sparse files in Windows.
* Sat Mar 19 2016 mpluskal@suse.com
- Update to version 7.07
  * Fixes v7.06 bug in creating multipart encrypted archives with
    incorrectly salted index
- Changes for 7.06
  * Fixes handling of some corrupted archives. Conforms to new spec
    zpaq205.pdf. New man page, Makefile, COPYING
- Ship shared library and devel package as well
- Various spec file improvements
* Sun Jan  3 2016 p.drouand@gmail.com
- Update to version 7.05
  * Fixed -method 111
  * fixes a valgrind warning (LZ77 read past end of input).
* Fri Apr 17 2015 mpluskal@suse.com
- Initial changelog for version 7.04
- Do not include build date and time
